@@ -63,9 +63,9 @@
 				new-args)))
 		  args)
 	(if unknown-openlets
-	    (apply func (reverse new-args))
+	    (apply func (reverse! new-args))
 	    (let-temporarily (((*s7* 'openlets) #f)) 
-	      (apply func (reverse new-args)))))))
+	      (apply func (reverse! new-args)))))))
 
   ;; one tricky thing here is that a mock object can be the let of with-let: (with-let (mock-port ...) ...)
   ;;   so a mock object's method can be called even when no argument is a mock object.  Even trickier
@@ -112,7 +112,9 @@
 		       'format             (with-mock-wrapper* #_format)
 		       'write              (with-mock-wrapper* #_write)
 		       'display            (with-mock-wrapper* #_display)
+		       'vector-dimension   (with-mock-wrapper #_vector-dimension)
 		       'vector-dimensions  (with-mock-wrapper #_vector-dimensions)
+		       'vector-rank        (with-mock-wrapper #_vector-rank)
 		       'fill!              (with-mock-wrapper* #_fill!)
 		       'vector-fill!       (with-mock-wrapper* #_vector-fill!)
 		       'vector->list       (with-mock-wrapper* #_vector->list)
@@ -620,7 +622,6 @@
   ;; from Wikipedia:
   ;; x + y =	[a+c, b+d]
   ;; x - y =	[a-d, b-c]
-  ;; x  y =	[min(ac, ad, bc, bd), max(ac, ad, bc, bd)]
   ;; x / y =	[min(a/c, a/d, b/c, b/d), max(a/c, a/d, b/c, b/d)]
   
   (define *interval*
